ALL_CATEGORIES = [
    "CMS",
    "Message boards",
    "Database managers",
    "Documentation",
    "Widgets",
    "Ecommerce",
    "Photo galleries",
    "Wikis",
    "Hosting panels",
    "Analytics",
    "Blogs",
    "JavaScript frameworks",
    "Issue trackers",
    "Video players",
    "Comment systems",
    "Security",
    "Font scripts",
    "Web frameworks",
    "Miscellaneous",
    "Editors",
    "LMS",
    "Web servers",
    "Caching",
    "Rich text editors",
    "JavaScript graphics",
    "Mobile frameworks",
    "Programming languages",
    "Operating systems",
    "Search engines",
    "Webmail",
    "CDN",
    "Marketing automation",
    "Web server extensions",
    "Databases",
    "Maps",
    "Advertising",
    "Network devices",
    "Media servers",
    "Webcams",
    "Payment processors",
    "Tag managers",
    "CI",
    "Control systems",
    "Remote access",
    "Development",
    "Network storage",
    "Feed readers",
    "DMS",
    "Page builders",
    "Live chat",
    "CRM",
    "SEO",
    "Accounting",
    "Cryptominers",
    "Static site generator",
    "User onboarding",
    "JavaScript libraries",
    "Containers",
    "PaaS",
    "IaaS",
    "Reverse proxies",
    "Load balancers",
    "UI frameworks",
    "Cookie compliance",
    "Accessibility",
    "Authentication",
    "SSL/TLS certificate authorities",
    "Affiliate programs",
    "Appointment scheduling",
    "Surveys",
    "A/B Testing",
    "Email",
    "Personalisation",
    "Retargeting",
    "RUM",
    "Geolocation",
    "WordPress themes",
    "Shopify themes",
    "Drupal themes",
    "Browser fingerprinting",
    "Loyalty & rewards",
    "Feature management",
    "Segmentation",
    "WordPress plugins",
    "Hosting",
    "Translation",
    "Reviews",
    "Buy now pay later",
    "Performance",
    "Reservations & delivery",
    "Referral marketing",
    "Digital asset management",
    "Content curation",
    "Customer data platform",
    "Cart abandonment",
    "Shipping carriers",
    "Shopify apps",
    "Recruitment & staffing",
    "Returns",
    "Livestreaming",
    "Ticket booking",
    "Augmented reality",
    "Cross border ecommerce",
    "Fulfilment",
    "Ecommerce frontends",
    "Domain parking",
    "Form builders",
    "Fundraising & donations",
]

DEFAULT_TRACKABLE_CATEGORIES = [
    "CMS",
    "Ecommerce",
    "Analytics",
    "LMS",
    "Marketing automation",
    "Advertising",
    "Payment processors",
    "Tag managers",
    "DMS",
    "Page builders",
    "Live chat",
    "CRM",
    "SEO",
    "Accounting",
    "User onboarding",
    "Affiliate programs",
    "Appointment scheduling",
    "Surveys",
    "A/B Testing",
    "Email",
    "Personalisation",
    "Retargeting",
    "Loyalty & rewards",
    "Reviews",
    "Buy now pay later",
    "Reservations & delivery",
    "Referral marketing",
    "Cart abandonment",
    "Shipping carriers",
    "Shopify apps",
    "Recruitment & staffing",
    "Returns",
    "Ticket booking",
    "Augmented reality",
    "Cross border ecommerce",
    "Fulfilment",
    "Form builders",
    "Fundraising & donations",
]
